//>>built
define("dojo/nls/pmbdojo_ko-kr",{"dijit/form/nls/validate":{invalidMessage:"\uc785\ub825\ub41c \uac12\uc774 \uc62c\ubc14\ub974\uc9c0 \uc54a\uc2b5\ub2c8\ub2e4.",missingMessage:"\uc774 \uac12\uc740 \ud544\uc218\uc785\ub2c8\ub2e4.",rangeMessage:"\uc774 \uac12\uc740 \ubc94\uc704\ub97c \ubc97\uc5b4\ub0a9\ub2c8\ub2e4.",_localized:{}},"dojo/cldr/nls/number":{scientificFormat:"#E0","currencySpacing-afterCurrency-currencyMatch":"[:^S:]",infinity:"\u221e",superscriptingExponent:"\u00d7",list:";",percentSign:"%",
minusSign:"-","currencySpacing-beforeCurrency-surroundingMatch":"[:digit:]","decimalFormat-short":"000\uc870","currencySpacing-afterCurrency-insertBetween":"\u00a0",nan:"NaN",plusSign:"+","currencySpacing-afterCurrency-surroundingMatch":"[:digit:]","currencySpacing-beforeCurrency-currencyMatch":"[:^S:]",currencyFormat:"\u00a4#,##0.00;(\u00a4#,##0.00)",perMille:"\u2030",group:",",percentFormat:"#,##0%","decimalFormat-long":"000\uc870",decimalFormat:"#,##0.###",decimal:".","currencySpacing-beforeCurrency-insertBetween":"\u00a0",
exponential:"E",_localized:{}},"dijit/form/nls/ComboBox":{previousMessage:"\uc774\uc804 \uc120\ud0dd\uc0ac\ud56d",nextMessage:"\uae30\ud0c0 \uc120\ud0dd\uc0ac\ud56d",_localized:{}},"dijit/nls/loading":{loadingState:"\ub85c\ub4dc \uc911...",errorState:"\uc8c4\uc1a1\ud569\ub2c8\ub2e4. \uc624\ub958\uac00 \ubc1c\uc0dd\ud588\uc2b5\ub2c8\ub2e4.",_localized:{}},"dijit/nls/common":{buttonOk:"\ud655\uc778",buttonCancel:"\ucde8\uc18c",buttonSave:"\uc800\uc7a5",itemClose:"\ub2eb\uae30",_localized:{}},"dijit/_editor/nls/commands":{bold:"\uad75\uc740\uccb4",
copy:"\ubcf5\uc0ac",cut:"\uc798\ub77c\ub0b4\uae30","delete":"\uc0ad\uc81c",indent:"\ub4e4\uc5ec\uc4f0\uae30",insertHorizontalRule:"\uc218\ud3c9 \uc790",insertOrderedList:"\ubc88\ud638 \ubaa9\ub85d",insertUnorderedList:"\uae00\uba38\ub9ac\ud45c \ubaa9\ub85d",italic:"\uae30\uc6b8\uc784\uccb4",justifyCenter:"\uac00\uc6b4\ub370 \ub9de\ucda4",justifyFull:"\uc591\ucabd \ub9de\ucda4",justifyLeft:"\uc67c\ucabd \ub9de\ucda4",justifyRight:"\uc624\ub978\ucabd \ub9de\ucda4",outdent:"\ub0b4\uc5b4\uc4f0\uae30",
paste:"\ubd99\uc5ec\ub123\uae30",redo:"\ub2e4\uc2dc \uc2e4\ud589",removeFormat:"\ud615\uc2dd \uc81c\uac70",selectAll:"\ubaa8\ub450 \uc120\ud0dd",strikethrough:"\ucde8\uc18c\uc120",subscript:"\uc544\ub798\ucca8\uc790",superscript:"\uc704\ucca8\uc790",underline:"\ubc11\uc904",undo:"\uc2e4\ud589 \ucde8\uc18c",unlink:"\ub9c1\ud06c \uc81c\uac70",createLink:"\ub9c1\ud06c \uc791\uc131",toggleDir:"\ubc29\ud5a5 \ud1a0\uae00",insertImage:"\uc774\ubbf8\uc9c0 \uc0bd\uc785",insertTable:"\ud14c\uc774\ube14 \uc0bd\uc785/\ud3b8\uc9d1",
toggleTableBorder:"\ud14c\uc774\ube14 \uc678\uacfd\uc120 \ud1a0\uae00",deleteTable:"\ud14c\uc774\ube14 \uc0ad\uc81c",tableProp:"\ud14c\uc774\ube14 \ud2b9\uc131",htmlToggle:"HTML \uc18c\uc2a4",foreColor:"\uc804\uacbd\uc0c9",hiliteColor:"\ubc30\uacbd\uc0c9",plainFormatBlock:"\ub2e8\ub77d \uc2a4\ud0c0\uc77c",formatBlock:"\ub2e8\ub77d \uc2a4\ud0c0\uc77c",fontSize:"\uae00\uaf34 \ud06c\uae30",fontName:"\uae00\uaf34 \uc774\ub984",tabIndent:"\ud0ed \ub4e4\uc5ec\uc4f0\uae30",fullScreen:"\uc804\uccb4 \ud654\uba74 \ud1a0\uae00",
viewSource:"HTML \uc18c\uc2a4 \ubcf4\uae30",print:"\uc778\uc1c4",newPage:"\uc0c8 \ud398\uc774\uc9c0",systemShortcut:'"${0}" \uc870\uce58\ub294 \ube0c\ub77c\uc6b0\uc800\uc5d0\uc11c \ud0a4\ubcf4\ub4dc \ub2e8\ucd95\ud0a4\ub97c \uc774\uc6a9\ud574\uc11c\ub9cc \uc0ac\uc6a9\ud560 \uc218 \uc788\uc2b5\ub2c8\ub2e4. ${1}\uc744(\ub97c) \uc0ac\uc6a9\ud558\uc2ed\uc2dc\uc624.',ctrlKey:"ctrl+${0}",appleKey:"\u2318${0}",_localized:{}},"dijit/_editor/nls/FontChoice":{1:"\uac00\uc7a5 \uc791\uac8c",2:"\uc870\uae08 \uc791\uac8c",
3:"\uc791\uac8c",4:"\uc911\uac04",5:"\ud06c\uac8c",6:"\uc870\uae08 \ud06c\uac8c",7:"\uac00\uc7a5 \ud06c\uac8c",fontSize:"\ud06c\uae30",fontName:"\uae00\uaf34",formatBlock:"\uc11c\uc2dd",serif:"serif","sans-serif":"sans-serif",monospace:"monospace",cursive:"cursive",fantasy:"fantasy",noFormat:"\uc5c6\uc74c",p:"\ub2e8\ub77d",h1:"\uc81c\ubaa9",h2:"\ubd80\uc81c\ubaa9",h3:"\ud558\uc704 \ubd80\uc81c\ubaa9",pre:"\uc11c\uc2dd\uc774 \uc9c0\uc815\ub428",_localized:{}},"dojox/editor/plugins/nls/latinEntities":{iexcl:"\uc5ed\ub290\ub08c\ud45c",
cent:"\uc13c\ud2b8 \uae30\ud638",pound:"\ud30c\uc6b4\ub4dc \uae30\ud638",curren:"\ud1b5\ud654 \uae30\ud638",yen:"\uc5d4 \uae30\ud638\n\uc704\uc548 \uae30\ud638",brvbar:"\ubd84\ud560\ub41c \ub9c9\ub300\n\ubd84\ud560\ub41c \uc138\ub85c \ub9c9\ub300",sect:"\uc139\uc158 \uae30\ud638",uml:"\ubd84\uc74c \uae30\ud638\n\uac04\uaca9 \ubd84\uc74c \uae30\ud638",copy:"\uc800\uc791\uad8c \uae30\ud638",ordf:"\uc5ec\uc131\ud615 \uc11c\uc218 \uae30\ud638",laquo:"\uc5ec\ub294 \uc774\uc911 \uaebe\uc1e0\uad04\ud638\n\uc5ec\ub294 \uc774\uc911 \uaebe\uc1e0\uad04\ud638",
not:"\ubd80\uc815 \uae30\ud638",shy:"\uc18c\ud504\ud2b8 \ud558\uc774\ud508\n\uc784\uc758 \ud558\uc774\ud508",reg:"\ub4f1\ub85d\uc0c1\ud45c \uae30\ud638\n\ub4f1\ub85d TM(Trade Mark) \uae30\ud638",macr:"\uc7a5\uc74c \uae30\ud638\n\uac04\uaca9 \uc7a5\uc74c \uae30\ud638\n\uc717\uc904\nAPL \uc717\ub9c9\ub300",deg:"\uc628\ub3c4 \uae30\ud638",plusmn:"\ud50c\ub7ec\uc2a4 \ub9c8\uc774\ub108\uc2a4 \uae30\ud638\n\ud50c\ub7ec\uc2a4 \ub610\ub294 \ub9c8\uc774\ub108\uc2a4 \uae30\ud638",sup2:"\uc704\ucca8\uc790 2\n\uc704\ucca8\uc790 \uc22b\uc790 2\n\uc81c\uacf1",
sup3:"\uc704\ucca8\uc790 3\n\uc704\ucca8\uc790 \uc22b\uc790 3\n\uc138\uc81c\uacf1",acute:"\uc591\uc74c \ubd80\ud638\n\uac04\uaca9 \uc591\uc74c \ubd80\ud638",micro:"\ub9c8\uc774\ud06c\ub85c \uae30\ud638",para:"\ub2e8\ub77d \uae30\ud638\n\ub2e8\ub77d \uae30\ud638",middot:"\uac00\uc6b4\ub370 \uc810\n\uc870\uc9c0\uc548 \uc27c\ud45c\n\uadf8\ub9ac\uc2a4 \uac00\uc6b4\ub370 \uc810",cedil:"\uc138\ub514\uc720\n\uac04\uaca9 \uc138\ub514\uc720",sup1:"\uc704\ucca8\uc790 1\n\uc704\ucca8\uc790 \uc22b\uc790 1",ordm:"\ub0a8\uc131\ud615 \uc11c\uc218 \uae30\ud638",
raquo:"\ub2eb\ub294 \uc774\uc911 \uaebe\uc1e0\uad04\ud638\n\ub2eb\ub294 \uc774\uc911 \uaebe\uc1e0\uad04\ud638",frac14:"\ubd84\uc218 \uc0ac\ubd84\uc758 \uc77c\n\ubd84\uc218 \uc0ac\ubd84\uc758 \uc77c",frac12:"\ubd84\uc218 \uc774\ubd84\uc758 \uc77c\n\ubd84\uc218 \uc774\ubd84\uc758 \uc77c",frac34:"\ubd84\uc218 \uc0ac\ubd84\uc758 \uc0bc\n\ubd84\uc218 \uc0ac\ubd84\uc758 \uc0bc",iquest:"\uc5ed\ubb3c\uc74c\ud45c\n\uc5ed\ubb3c\uc74c\ud45c",Agrave:"\ub77c\ud2f4 \ub300\ubb38\uc790 A \uc704 \uc5b5\uc74c \ubd80\ud638\n\ub77c\ud2f4 \ub300\ubb38\uc790 A \uc704 \uc5b5\uc74c \ubd80\ud638",
Aacute:"\ub77c\ud2f4 \ub300\ubb38\uc790 A \uc704 \uc561\uc13c\ud2b8",Acirc:"\ub77c\ud2f4 \ub300\ubb38\uc790 A \uc704 \uc11c\ucef4\ud50c\ub809\uc2a4",Atilde:"\ub77c\ud2f4 \ub300\ubb38\uc790 A \uc704 \ubb3c\uacb0 \uae30\ud638",Auml:"\ub77c\ud2f4 \ub300\ubb38\uc790 A \uc704 \ubd84\uc74c \uae30\ud638",Aring:"\ub77c\ud2f4 \ub300\ubb38\uc790 A \uc704 \uc6d0 \ud45c\uc2dc\n\ub77c\ud2f4 \ub300\ubb38\uc790 A \uc704 \uc6d0",AElig:"\ub77c\ud2f4 \ub300\ubb38\uc790 AE\n\ub77c\ud2f4 \ub300\ubb38\uc790 \ud569\uc790 AE",
Ccedil:"\ub77c\ud2f4 \ub300\ubb38\uc790 C \uc138\ub514\uc720",Egrave:"\ub77c\ud2f4 \ub300\ubb38\uc790 E \uc704 \uc5b5\uc74c \ubd80\ud638",Eacute:"\ub77c\ud2f4 \ub300\ubb38\uc790 E \uc704 \uc561\uc13c\ud2b8",Ecirc:"\ub77c\ud2f4 \ub300\ubb38\uc790 E \uc704 \uc11c\ucef4\ud50c\ub809\uc2a4",Euml:"\ub77c\ud2f4 \ub300\ubb38\uc790 E \uc704 \ubd84\uc74c \uae30\ud638",Igrave:"\ub77c\ud2f4 \ub300\ubb38\uc790 I \uc704 \uc5b5\uc74c \ubd80\ud638",Iacute:"\ub77c\ud2f4 \ub300\ubb38\uc790 I \uc704 \uc561\uc13c\ud2b8",
Icirc:"\ub77c\ud2f4 \ub300\ubb38\uc790 I \uc704 \uc11c\ucef4\ud50c\ub809\uc2a4",Iuml:"\ub77c\ud2f4 \ub300\ubb38\uc790 I \uc704 \ubd84\uc74c \uae30\ud638",ETH:"\ub77c\ud2f4 \ub300\ubb38\uc790 ETH",Ntilde:"\ub77c\ud2f4 \ub300\ubb38\uc790 N \uc704 \ubb3c\uacb0 \uae30\ud638",Ograve:"\ub77c\ud2f4 \ub300\ubb38\uc790 O \uc704 \uc5b5\uc74c \ubd80\ud638",Oacute:"\ub77c\ud2f4 \ub300\ubb38\uc790 O \uc704 \uc561\uc13c\ud2b8",Ocirc:"\ub77c\ud2f4 \ub300\ubb38\uc790 O \uc704 \uc11c\ucef4\ud50c\ub809\uc2a4",Otilde:"\ub77c\ud2f4 \ub300\ubb38\uc790 O \uc704 \ubb3c\uacb0 \uae30\ud638",
Ouml:"\ub77c\ud2f4 \ub300\ubb38\uc790 O \uc704 \ubd84\uc74c \uae30\ud638",times:"\uacf1\uc148 \uae30\ud638",Oslash:"\uc2a4\ud2b8\ub85c\ud06c\uac00 \uc788\ub294 \ub77c\ud2f4 \ub300\ubb38\uc790 O\n\ub77c\ud2f4 \ub300\ubb38\uc790 O \uc2ac\ub798\uc2dc",Ugrave:"\ub77c\ud2f4 \ub300\ubb38\uc790 U \uc704 \uc5b5\uc74c \ubd80\ud638",Uacute:"\ub77c\ud2f4 \ub300\ubb38\uc790 U \uc704 \uc561\uc13c\ud2b8",Ucirc:"\ub77c\ud2f4 \ub300\ubb38\uc790 U \uc704 \uc11c\ucef4\ud50c\ub809\uc2a4",Uuml:"\ub77c\ud2f4 \ub300\ubb38\uc790 U \uc704 \ubd84\uc74c \uae30\ud638",
Yacute:"\ub77c\ud2f4 \ub300\ubb38\uc790 Y \uc704 \uc561\uc13c\ud2b8",THORN:"\ub77c\ud2f4 \ub300\ubb38\uc790 THORN",szlig:"\ub77c\ud2f4 \uc18c\ubb38\uc790 sharp\ub77c\ud2f4 \uc18c\ubb38\uc790 sharp",agrave:"\ub77c\ud2f4 \uc18c\ubb38\uc790 a \uc704 \uc5b5\uc74c \ubd80\ud638\n\ub77c\ud2f4 \uc18c\ubb38\uc790 a \uc704 \uc5b5\uc74c \ubd80\ud638",aacute:"\ub77c\ud2f4 \uc18c\ubb38\uc790 a \uc704 \uc561\uc13c\ud2b8",acirc:"\ub77c\ud2f4 \uc18c\ubb38\uc790 a \uc704 \uc11c\ucef4\ud50c\ub809\uc2a4",atilde:"\ub77c\ud2f4 \uc18c\ubb38\uc790 a \uc704 \ubb3c\uacb0 \uae30\ud638",
auml:"\ub77c\ud2f4 \uc18c\ubb38\uc790 a \uc704 \ubd84\uc74c \uae30\ud638",aring:"\ub77c\ud2f4 \uc18c\ubb38\uc790 a \uc704 \uc6d0\n\ub77c\ud2f4 \uc18c\ubb38\uc790 a \uc704 \uc6d0",aelig:"\ub77c\ud2f4 \uc18c\ubb38\uc790 ae\n\ub77c\ud2f4 \uc18c\ubb38\uc790 \ud569\uc790 ae",ccedil:"\ub77c\ud2f4 \uc18c\ubb38\uc790 c \uc138\ub514\uc720",egrave:"\ub77c\ud2f4 \uc18c\ubb38\uc790 e  \uc704 \uc5b5\uc74c \ubd80\ud638",eacute:"\ub77c\ud2f4 \uc18c\ubb38\uc790 e \uc704 \uc561\uc13c\ud2b8",ecirc:"\ub77c\ud2f4 \uc18c\ubb38\uc790 e \uc704 \uc11c\ucef4\ud50c\ub809\uc2a4",
euml:"\ub77c\ud2f4 \uc18c\ubb38\uc790 e \uc704 \ubd84\uc74c \uae30\ud638",igrave:"\ub77c\ud2f4 \uc18c\ubb38\uc790 i \uc704 \uc5b5\uc74c \ubd80\ud638",iacute:"\ub77c\ud2f4 \uc18c\ubb38\uc790 i \uc561\uc13c\ud2b8",icirc:"\ub77c\ud2f4 \uc18c\ubb38\uc790 i \uc704 \uc11c\ucef4\ud50c\ub809\uc2a4",iuml:"\ub77c\ud2f4 \uc18c\ubb38\uc790 i \uc704 \ubd84\uc74c \uae30\ud638",eth:"\ub77c\ud2f4 \uc18c\ubb38\uc790 eth",ntilde:"\ub77c\ud2f4 \uc18c\ubb38\uc790 n \uc704 \ubb3c\uacb0 \uae30\ud638",ograve:"\ub77c\ud2f4 \uc18c\ubb38\uc790 o \uc704 \uc5b5\uc74c \ubd80\ud638",
oacute:"\ub77c\ud2f4 \uc18c\ubb38\uc790 o \uc704 \uc561\uc13c\ud2b8",ocirc:"\ub77c\ud2f4 \uc18c\ubb38\uc790 o \uc704 \uc11c\ucef4\ud50c\ub809\uc2a4",otilde:"\ub77c\ud2f4 \uc18c\ubb38\uc790 o \uc704 \ubb3c\uacb0 \uae30\ud638",ouml:"\ub77c\ud2f4 \uc18c\ubb38\uc790 o \uc704 \ubd84\uc74c \uae30\ud638",divide:"\ub098\ub217\uc148 \uae30\ud638",oslash:"\uc2a4\ud2b8\ub85c\ud06c\uac00 \uc788\ub294 \ub77c\ud2f4 \uc18c\ubb38\uc790 o\n\ub77c\ud2f4 \uc18c\ubb38\uc790 o \uc2ac\ub798\uc2dc",ugrave:"\ub77c\ud2f4 \uc18c\ubb38\uc790 u \uc704 \uc5b5\uc74c \ubd80\ud638",
uacute:"\ub77c\ud2f4 \uc18c\ubb38\uc790 u \uc704 \uc561\uc13c\ud2b8",ucirc:"\ub77c\ud2f4 \uc18c\ubb38\uc790 u \uc704 \uc11c\ucef4\ud50c\ub809\uc2a4",uuml:"\ub77c\ud2f4 \uc18c\ubb38\uc790 u \uc704 \ubd84\uc74c \uae30\ud638",yacute:"\ub77c\ud2f4 \uc18c\ubb38\uc790 y \uc704 \uc561\uc13c\ud2b8",thorn:"\ub77c\ud2f4 \uc18c\ubb38\uc790 thorn",yuml:"\ub77c\ud2f4 \uc18c\ubb38\uc790 y \uc704 \ubd84\uc74c \uae30\ud638",fnof:"\ub77c\ud2f4 \uc18c\ubb38\uc790 f\uc5d0 \uace0\ub9ac \ucca8\ubd80\n\uae30\ub2a5\n\ud50c\ub85c\ub9b0",
Alpha:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 alpha",Beta:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 beta",Gamma:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 gamma",Delta:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 delta",Epsilon:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 epsilon",Zeta:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 zeta",Eta:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 eta",Theta:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 theta",Iota:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 iota",Kappa:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 kappa",
Lambda:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 lambda",Mu:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 mu",Nu:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 nu",Xi:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 xi",Omicron:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 omicron",Pi:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 pi",Rho:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 rho",Sigma:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 sigma",Tau:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 tau",Upsilon:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 upsilon",Phi:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 phi",
Chi:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 chi",Psi:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 psi",Omega:"\uadf8\ub9ac\uc2a4 \ub300\ubb38\uc790 omega",alpha:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 alpha",beta:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 beta",gamma:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 gamma",delta:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 delta",epsilon:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 epsilon",zeta:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 zeta",eta:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 eta",
theta:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 theta",iota:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 iota",kappa:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 kappa",lambda:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 lambda",mu:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 mu",nu:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 nu",xi:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 xi",omicron:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 omicron",pi:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 pi",rho:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 rho",sigmaf:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 final sigma",
sigma:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 sigma",tau:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 tau",upsilon:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 upsilon",phi:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 phi",chi:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 chi",psi:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 psi",omega:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 omega",thetasym:"\uadf8\ub9ac\uc2a4 \uc18c\ubb38\uc790 theta symbol",upsih:"\uadf8\ub9ac\uc2a4 upsilon\uc5d0 \uace0\ub9ac \uae30\ud638",piv:"\uadf8\ub9ac\uc2a4 pi symbol",
bull:"\uae00\uba38\ub9ac \uae30\ud638\n\uac80\uc740\uc0c9 \uc791\uc740 \uc6d0",hellip:"\uc0dd\ub7b5 \uae30\ud638\n\uc138 \uc810",prime:"\uae30\ubcf8\n\ubd84\n\ud53c\ud2b8",Prime:"\uc774\uc911 \uc2e4\uc120 \uae30\ubcf8\n\ucd08\n\uc778\uce58",oline:"\uc717 \uc904\n\ucde8\uc18c\uc120",frasl:"\ubd84\uc218 \uc2ac\ub798\uc2dc",weierp:"\uc2a4\ud06c\ub9bd\ud2b8 \ub300\ubb38\uc790 P\n\uba71\uc9d1\ud569\n\ubc14\uc774\uc5d0\ub974\uc288\ud2b8\ub77c\uc2a4 p",image:"\uac80\uc815 \uae00\uc790 \ub300\ubb38\uc790 I\n\uc774\ubbf8\uc9c0 \ud30c\ud2b8",
real:"\uac80\uc815 \uae00\uc790 \ub300\ubb38\uc790 R\n\uc2e4\uc81c \ud30c\ud2b8 \uae30\ud638",trade:"TM(trade mark) \uae30\ud638",alefsym:"Alef \uae30\ud638\n\uccab \ubc88\uc9f8 \ucd08\ud55c\uae30\uc218",larr:"\uc67c\ucabd \ud654\uc0b4\ud45c",uarr:"\uc704\ucabd \ud654\uc0b4\ud45c",rarr:"\uc624\ub978\ucabd \ud654\uc0b4\ud45c",darr:"\uc544\ub798\ucabd \ud654\uc0b4\ud45c",harr:"\uc88c\uc6b0 \ud654\uc0b4\ud45c",crarr:"\ubaa8\uc11c\ub9ac\uac00 \uc67c\ucabd\uc73c\ub85c \ud5a5\ud558\ub294 \uc544\ub798\ucabd \ubc29\ud5a5 \ud654\uc0b4\ud45c\n\uce90\ub9ac\uc9c0 \ub9ac\ud134",
lArr:"\uc67c\ucabd \uc774\uc911 \ud654\uc0b4\ud45c",uArr:"\uc704\ucabd \uc774\uc911 \ud654\uc0b4\ud45c",rArr:"\ub450 \uc904\uc9dc\ub9ac \uc624\ub978\ucabd \ud654\uc0b4\ud45c",dArr:"\uc544\ub798\ucabd \uc774\uc911 \ud654\uc0b4\ud45c",hArr:"\ub450 \uc904\uc9dc\ub9ac \uc591\ubc29\ud5a5 \ud654\uc0b4\ud45c",forall:"\ubaa8\ub450",part:"\ubd80\ubd84\uc801\uc73c\ub85c \ub2e4\ub984",exist:"\uc874\uc7ac",empty:"\ube48 \uc138\ud2b8\n\ub110 \uc138\ud2b8\n\uc9c0\ub984",nabla:"\ub098\ube14\ub77c\n\ud6c4\uc9c4\ucc28\ubd84",
isin:"..\uc758 \uc694\uc18c",notin:"..\uc758 \uc694\uc18c\uac00 \uc544\ub2d8",ni:"\uba64\ubc84\ub85c \ud3ec\ud568",prod:"\ubb34\ud55c \uae09\uc218\n\uc81c\ud488 \uae30\ud638",sum:"\ubb34\ud55c \uae09\uc218 \ud569",minus:"\ub9c8\uc774\ub108\uc2a4 \uae30\ud638",lowast:"\ubcc4\ud45c \uc5f0\uc0b0\uc790",radic:"\uc81c\uacf1\uadfc\n\uadfc\ud638",prop:"\ube44\ub840",infin:"\ubb34\ud55c\ub300",ang:"\uac01\ub3c4",and:"\ub17c\ub9ac \ubc0f \n\uc410\uae30\ud615",or:"\ub17c\ub9ac \ub610\ub294 \nV\uc790\ud615",
cap:"\uad50\uc9d1\ud569\n\uad50\uc9d1\ud569",cup:"\ud569\uc9d1\ud569\n\ud569\uc9d1\ud569","int":"\uc801\ubd84",there4:"\ub530\ub77c\uc11c",sim:"\ubb3c\uacb0 \uae30\ud638 \uc5f0\uc0b0\uc790\n\ubcc0\ud615\n\uc720\uc0ac",cong:"\ub300\ub7b5 \uac19\ub2e4",asymp:"\uadfc\uc0ac\uac12 \uae30\ud638\n\uc810\uadfc",ne:"\uac19\uc9c0 \uc54a\ub2e4",equiv:"\ud569\ub3d9 \uae30\ud638",le:"\uc801\uac70\ub098 \uac19\ub2e4",ge:"\ud06c\uac70\ub098 \uac19\ub2e4",sub:"\ubd80\ubd84 \uc9d1\ud569",sup:"\uc0c1\uc704 \uc9d1\ud569",
nsub:"\ubd80\ubd84 \uc9d1\ud569\uc774 \uc544\ub2d8",sube:"\ubd80\ubd84 \uc9d1\ud569\uc774\uac70\ub098 \uac19\ub2e4",supe:"\uc0c1\uc704 \uc9d1\ud569\uc774\uac70\ub098 \uac19\ub2e4",oplus:"\uc6d0 \uc548\uc758 \ud50c\ub7ec\uc2a4\n\uc9c1\ud569",otimes:"\uc6d0 \uc548\uc758 \uacf1\ud558\uae30 \uae30\ud638\n\ubca1\ud130\uc801",perp:"\uc5c5 \ud0dd\n\uc9c1\uad50\n\uc218\uc9c1",sdot:"\uc810 \uc5f0\uc0b0\uc790",lceil:"\uc67c\ucabd \uc717\uba74\nAPL \uc5c5\uc2a4\ud0c0\uc77c",rceil:"\uc624\ub978\ucabd \uc717\uba74",
lfloor:"\uc67c\ucabd \ubc11\uba74\nAPL \ub2e4\uc6b4\uc2a4\ud0c0\uc77c",rfloor:"\uc624\ub978\ucabd \ubc11\uba74",lang:"\uc5ec\ub294 \uaebe\uc1e0\uad04\ud638",rang:"\ub2eb\ub294 \uaebe\uc1e0\uad04\ud638",loz:"\ub9c8\ub984\ubaa8",spades:"\ube14\ub799 \uc2a4\ud398\uc774\ub4dc",clubs:"\ube14\ub799 \ud06c\ub85c\ubc84\n\ud06c\ub85c\ubc84",hearts:"\ube14\ub799 \ud558\ud2b8\n\ubc1c\ub80c\ud0c0\uc778",diams:"\ube14\ub799 \ub2e4\uc774\uc544\ubaac\ub4dc",OElig:"\ub77c\ud2f4 \ub300\ubb38\uc790 \ud569\uc790 OE",
oelig:"\ub77c\ud2f4 \uc18c\ubb38\uc790 \ud569\uc790 oe",Scaron:"\ub77c\ud2f4 \ub300\ubb38\uc790 S \uc704 v \ud45c ",scaron:"\ub77c\ud2f4 \uc18c\ubb38\uc790 s \uc704 v \ud45c",Yuml:"\ub77c\ud2f4 \ub300\ubb38\uc790 Y \uc704 \ubd84\uc74c \uae30\ud638",circ:"\uc704 \uaebe\uae30",tilde:"\uc18c\ubb38\uc790 \uc704 \ubb3c\uacb0 \uae30\ud638",ensp:"en \uacf5\uac04",emsp:"em \uacf5\uac04",thinsp:"\uc52c \uacf5\uac04",zwnj:"\ud3ed\uc774 0\uc774\uace0, \uc5f0\uacb0\uc790 \uc5c6\uc74c",zwj:"\ud3ed\uc774 0\uc778 \uc5f0\uacb0\uc790",
lrm:"\uc67c\ucabd\uc5d0\uc11c \uc624\ub978\ucabd\uc73c\ub85c \ud45c\uc2dc",rlm:"\uc624\ub978\ucabd\uc5d0\uc11c \uc67c\ucabd\uc73c\ub85c \ud45c\uc2dc",ndash:"en \ub300\uc2dc ",mdash:"em \ub300\uc2dc",lsquo:"\uc5ec\ub294 \uc791\uc740 \ub530\uc634\ud45c",rsquo:"\ub2eb\ub294 \uc791\uc740 \ub530\uc634\ud45c",sbquo:"\ud558\ubd80 \uc791\uc740 \ub530\uc634\ud45c",ldquo:"\uc5ec\ub294 \ud070 \ub530\uc634\ud45c",rdquo:"\ub2eb\ub294 \ud070 \ub530\uc634\ud45c",bdquo:"\ud558\ubd80 \ud070 \ub530\uc634\ud45c",dagger:"\uce7c \ubaa8\uc591",
Dagger:"\uc774\uc911 \uce7c \ubaa8\uc591",permil:"\ud37c\ubc00 \uae30\ud638",lsaquo:"\uc5ec\ub294 \ub2e8\uc77c \uaebe\uc1e0\uad04\ud638",rsaquo:"\ub2eb\ub294 \ub2e8\uc77c \uaebe\uc1e0\uad04\ud638",euro:"euro \uae30\ud638",_localized:{}},"dojox/editor/plugins/nls/InsertEntity":{insertEntity:"\uae30\ud638 \uc0bd\uc785",_localized:{}},"dojo/nls/colors":{aliceblue:"\uc568\ub9ac\uc2a4 \ube14\ub8e8(alice blue)",antiquewhite:"\uc564\ud2f1 \ud654\uc774\ud2b8(antique white)",aqua:"\uc544\ucfe0\uc544(aqua)",
aquamarine:"\uc544\ucfe0\uc544\ub9c8\ub9b0(aquamarine)",azure:"\uc560\uc96c\uc5b4(azure)",beige:"\ubca0\uc774\uc9c0(beige)",bisque:"\ube44\uc2a4\ud06c(bisque)",black:"\ube14\ub799(black)",blanchedalmond:"\ube14\ub79c\uce58 \uc544\ubaac\ub4dc(blanched almond)",blue:"\ube14\ub8e8(blue)",blueviolet:"\ube14\ub8e8 \ubc14\uc774\uc62c\ub81b(blue-violet)",brown:"\ube0c\ub77c\uc6b4(brown)",burlywood:"\ubc8c\ub9ac\uc6b0\ub4dc(burlywood)",cadetblue:"\uce74\ub383 \ube14\ub8e8(cadet blue)",chartreuse:"\uc0e4\ub974\ud2b8\ub8b0\uc988(chartreuse)",
chocolate:"\ucd08\ucf5c\ub81b(chocolate)",coral:"\ucf54\ub784(coral)",cornflowerblue:"\ucf58\ud50c\ub77c\uc6cc \ube14\ub8e8(cornflower blue)",cornsilk:"\ucf58\uc2e4\ud06c(cornsilk)",crimson:"\ud06c\ub9bc\uc2a8(crimson)",cyan:"\uc2dc\uc548(cyan)",darkblue:"\ub2e4\ud06c \ube14\ub8e8(dark blue)",darkcyan:"\ub2e4\ud06c \uc2dc\uc548(dark cyan)",darkgoldenrod:"\ub2e4\ud06c \uace8\ub4e0\ub85c\ub4dc(dark goldenrod)",darkgray:"\ub2e4\ud06c \uadf8\ub808\uc774(dark gray)",darkgreen:"\ub2e4\ud06c \uadf8\ub9b0(dark green)",
darkgrey:"\ub2e4\ud06c \uadf8\ub808\uc774(dark gray)",darkkhaki:"\ub2e4\ud06c \uce74\ud0a4(dark khaki)",darkmagenta:"\ub2e4\ud06c \ub9c8\uc820\ud0c0(dark magenta)",darkolivegreen:"\ub2e4\ud06c \uc62c\ub9ac\ube0c \uadf8\ub9b0(dark olive green)",darkorange:"\ub2e4\ud06c \uc624\ub80c\uc9c0(dark orange)",darkorchid:"\ub2e4\ud06c \uc624\ud0a4\ub4dc(dark orchid)",darkred:"\ub2e4\ud06c \ub808\ub4dc(dark red)",darksalmon:"\ub2e4\ud06c \uc0d0\ubaac(dark salmon)",darkseagreen:"\ub2e4\ud06c \uc528 \uadf8\ub9b0(dark sea green)",
darkslateblue:"\ub2e4\ud06c \uc2ac\ub808\uc774\ud2b8 \ube14\ub8e8(dark slate blue)",darkslategray:"\ub2e4\ud06c \uc2ac\ub808\uc774\ud2b8 \uadf8\ub808\uc774(dark slate gray)",darkslategrey:"\ub2e4\ud06c \uc2ac\ub808\uc774\ud2b8 \uadf8\ub808\uc774(dark slate gray)",darkturquoise:"\ub2e4\ud06c \ud130\ucf70\uc988(dark turquoise)",darkviolet:"\ub2e4\ud06c \ubc14\uc774\uc62c\ub81b(dark violet)",deeppink:"\ub525 \ud551\ud06c(deep pink)",deepskyblue:"\ub525 \uc2a4\uce74\uc774 \ube14\ub8e8(deep sky blue)",
dimgray:"\ub524 \uadf8\ub808\uc774(dim gray)",dimgrey:"\ub524 \uadf8\ub808\uc774(dim gray)",dodgerblue:"\ub2e4\uc800 \ube14\ub8e8(dodger blue)",firebrick:"\ud30c\uc774\uc5b4 \ube0c\ub9ad(fire brick)",floralwhite:"\ud50c\ub85c\ub784 \ud654\uc774\ud2b8(floral white)",forestgreen:"\ud3ec\ub808\uc2a4\ud2b8 \uadf8\ub9b0(forest green)",fuchsia:"\ud6c4\ud06c\uc0e4(fuchsia)",gainsboro:"\uac8c\uc778\uc2a4\ube0c\ub85c(gainsboro)",ghostwhite:"\uace0\uc2a4\ud2b8 \ud654\uc774\ud2b8(ghost white)",gold:"\uace8\ub4dc(gold)",
goldenrod:"\uace8\ub4e0\ub85c\ub4dc(goldenrod)",gray:"\uadf8\ub808\uc774(gray)",green:"\uadf8\ub9b0(green)",greenyellow:"\uadf8\ub9b0 \uc610\ub85c\uc6b0(green-yellow)",grey:"\uadf8\ub808\uc774(gray)",honeydew:"\ud5c8\ub2c8\ub4c0(honeydew)",hotpink:"\ud56b \ud551\ud06c(hot pink)",indianred:"\uc778\ub514\uc548 \ub808\ub4dc(indian red)",indigo:"\uc778\ub514\uace0(indigo)",ivory:"\uc544\uc774\ubcf4\ub9ac(ivory)",khaki:"\uce74\ud0a4(khaki)",lavender:"\ub77c\ubca4\ub354(lavender)",lavenderblush:"\ub77c\ubca4\ub354 \ube14\ub7ec\uc26c(lavender blush)",
lawngreen:"\ub860 \uadf8\ub9b0(lawn green)",lemonchiffon:"\ub808\ubaac \uc26c\ud3f0(lemon chiffon)",lightblue:"\ub77c\uc774\ud2b8 \ube14\ub8e8(light blue)",lightcoral:"\ub77c\uc774\ud2b8 \ucf54\ub784(light coral)",lightcyan:"\ub77c\uc774\ud2b8 \uc2dc\uc548(light cyan)",lightgoldenrodyellow:"\ub77c\uc774\ud2b8 \uace8\ub4e0\ub85c\ub4dc \uc610\ub85c\uc6b0(light goldenrod yellow)",lightgray:"\ub77c\uc774\ud2b8 \uadf8\ub808\uc774(light gray)",lightgreen:"\ub77c\uc774\ud2b8 \uadf8\ub9b0(light green)",lightgrey:"\ub77c\uc774\ud2b8 \uadf8\ub808\uc774(light gray)",
lightpink:"\ub77c\uc774\ud2b8 \ud551\ud06c(light pink)",lightsalmon:"\ub77c\uc774\ud2b8 \uc0d0\ubaac(light salmon)",lightseagreen:"\ub77c\uc774\ud2b8 \uc528 \uadf8\ub9b0(light sea green)",lightskyblue:"\ub77c\uc774\ud2b8 \uc2a4\uce74\uc774 \ube14\ub8e8(light sky blue)",lightslategray:"\ub77c\uc774\ud2b8 \uc2ac\ub808\uc774\ud2b8 \uadf8\ub808\uc774(light slate gray)",lightslategrey:"\ub77c\uc774\ud2b8 \uc2ac\ub808\uc774\ud2b8 \uadf8\ub808\uc774(light slate gray)",lightsteelblue:"\ub77c\uc774\ud2b8 \uc2a4\ud2f8 \ube14\ub8e8(light steel blue)",
lightyellow:"\ub77c\uc774\ud2b8 \uc610\ub85c\uc6b0(light yellow)",lime:"\ub77c\uc784(lime)",limegreen:"\ub77c\uc784 \uadf8\ub9b0(lime green)",linen:"\ub9ac\ub128(linen)",magenta:"\ub9c8\uc820\ud0c0(magenta)",maroon:"\ub9c8\ub8ec(maroon)",mediumaquamarine:"\ubbf8\ub514\uc5c4 \uc544\ucfe0\uc544\ub9c8\ub9b0(medium aquamarine)",mediumblue:"\ubbf8\ub514\uc5c4 \ube14\ub8e8(medium blue)",mediumorchid:"\ubbf8\ub514\uc5c4 \uc624\ud0a4\ub4dc(medium orchid)",mediumpurple:"\ubbf8\ub514\uc5c4 \ud37c\ud50c(medium purple)",
mediumseagreen:"\ubbf8\ub514\uc5c4 \uc528 \uadf8\ub9b0(medium sea green)",mediumslateblue:"\ubbf8\ub514\uc5c4 \uc2ac\ub808\uc774\ud2b8 \ube14\ub8e8(medium slate blue)",mediumspringgreen:"\ubbf8\ub514\uc5c4 \uc2a4\ud504\ub9c1 \uadf8\ub9b0(medium spring green)",mediumturquoise:"\ubbf8\ub514\uc5c4 \ud130\ucf70\uc988(medium turquoise)",mediumvioletred:"\ubbf8\ub514\uc5c4 \ubc14\uc774\uc62c\ub81b \ub808\ub4dc(medium violet-red)",midnightblue:"\ubbf8\ub4dc\ub098\uc787 \ube14\ub8e8(midnight blue)",mintcream:"\ubbfc\ud2b8 \ud06c\ub9bc(mint cream)",
mistyrose:"\ubbf8\uc2a4\ud2f0 \ub85c\uc988(misty rose)",moccasin:"\ubaa8\uce74\uc2e0(moccasin)",navajowhite:"\ub098\ubc14\ud638 \ud654\uc774\ud2b8(navajo white)",navy:"\ub124\uc774\ube44(navy)",oldlace:"\uc62c\ub4dc \ub808\uc774\uc2a4(old lace)",olive:"\uc62c\ub9ac\ube0c(olive)",olivedrab:"\uc62c\ub9ac\ube0c \ub4dc\ub7a9(olive drab)",orange:"\uc624\ub80c\uc9c0(orange)",orangered:"\uc624\ub80c\uc9c0 \ub808\ub4dc(orange red)",orchid:"\uc624\ud0a4\ub4dc(orchid)",palegoldenrod:"\ud398\uc77c \uace8\ub4e0\ub85c\ub4dc(pale goldenrod)",
palegreen:"\ud398\uc77c \uadf8\ub9b0(pale green)",paleturquoise:"\ud398\uc77c \ud130\ucf70\uc988(pale turquoise)",palevioletred:"\ud398\uc77c \ubc14\uc774\uc62c\ub81b \ub808\ub4dc(pale violet-red)",papayawhip:"\ud30c\ud30c\uc57c \ud729(papaya whip)",peachpuff:"\ud53c\uce58 \ud37c\ud504(peach puff)",peru:"\ud398\ub8e8(peru)",pink:"\ud551\ud06c(pink)",plum:"\ud50c\ub7fc(plum)",powderblue:"\ud30c\uc6b0\ub354 \ube14\ub8e8(powder blue)",purple:"\ud37c\ud50c(purple)",red:"\ub808\ub4dc(red)",rosybrown:"\ub85c\uc9c0 \ube0c\ub77c\uc6b4(rosy brown)",
royalblue:"\ub85c\uc584 \ube14\ub8e8(royal blue)",saddlebrown:"\uc0c8\ub4e4 \ube0c\ub77c\uc6b4(saddle brown)",salmon:"\uc0d0\ubaac(salmon)",sandybrown:"\uc0cc\ub514 \ube0c\ub77c\uc6b4(sandy brown)",seagreen:"\uc528 \uadf8\ub9b0(sea green)",seashell:"\uc528\uc258(seashell)",sienna:"\uc2dc\uc5d0\ub098(sienna)",silver:"\uc2e4\ubc84(silver)",skyblue:"\uc2a4\uce74\uc774 \ube14\ub8e8(sky blue)",slateblue:"\uc2ac\ub808\uc774\ud2b8 \ube14\ub8e8(slate blue)",slategray:"\uc2ac\ub808\uc774\ud2b8 \uadf8\ub808\uc774(slate gray)",
slategrey:"\uc2ac\ub808\uc774\ud2b8 \uadf8\ub808\uc774(slate gray)",snow:"\uc2a4\ub178\uc6b0(snow)",springgreen:"\uc2a4\ud504\ub9c1 \uadf8\ub9b0(spring green)",steelblue:"\uc2a4\ud2f8 \ube14\ub8e8(steel blue)",tan:"\ud0e0(tan)",teal:"\ud2f8(teal)",thistle:"\uc2dc\uc2ac(thistle)",tomato:"\ud1a0\ub9c8\ud1a0(tomato)",transparent:"\ud22c\uba85(transparent)",turquoise:"\ud130\ucf70\uc988(turquoise)",violet:"\ubc14\uc774\uc62c\ub81b(violet)",wheat:"\ud718\ud2b8(wheat)",white:"\ud654\uc774\ud2b8(white)",
whitesmoke:"\ud654\uc774\ud2b8 \uc2a4\ubaa8\ud06c(white smoke)",yellow:"\uc610\ub85c\uc6b0(yellow)",yellowgreen:"\uc610\ub85c\uc6b0 \uadf8\ub9b0(yellow green)",_localized:{}},"dojox/widget/nls/ColorPicker":{redLabel:"R",greenLabel:"G",blueLabel:"B",hueLabel:"H",saturationLabel:"S",valueLabel:"V",degLabel:"\u00b0",hexLabel:"16\uc9c4",huePickerTitle:"\uc0c9\uc0c1 \uc120\ud0dd\uc790",saturationPickerTitle:"\ucc44\ub3c4 \uc120\ud0dd\uc790",_localized:{}},"dojox/editor/plugins/nls/TableDialog":{insertTableTitle:"\ud14c\uc774\ube14 \uc0bd\uc785",
modifyTableTitle:"\ud14c\uc774\ube14 \uc218\uc815",rows:"\ud589:",columns:"\uc5f4:",align:"\ub9de\ucd94\uae30:",cellPadding:"\uc140 \ucc44\uc6b0\uae30:",cellSpacing:"\uc140 \uac04\uaca9:",tableWidth:"\ud14c\uc774\ube14 \ub108\ube44:",backgroundColor:"\ubc30\uacbd\uc0c9:",borderColor:"\ud14c\ub450\ub9ac \uc0c9:",borderThickness:"\ud14c\ub450\ub9ac \ub450\uaed8",percent:"\ubc31\ubd84\uc728",pixels:"\ud53d\uc140","default":"\uae30\ubcf8\uac12",left:"\uc67c\ucabd",center:"\uac00\uc6b4\ub370",right:"\uc624\ub978\ucabd",
buttonSet:"\uc124\uc815",buttonInsert:"\uc0bd\uc785",buttonCancel:"\ucde8\uc18c",selectTableLabel:"\ud14c\uc774\ube14 \uc120\ud0dd",insertTableRowBeforeLabel:"\uc0ac\uc804 \ud589 \ucd94\uac00",insertTableRowAfterLabel:"\uc0ac\ud6c4 \ud589 \ucd94\uac00",insertTableColumnBeforeLabel:"\uc0ac\uc804 \uc5f4 \ucd94\uac00",insertTableColumnAfterLabel:"\uc0ac\ud6c4 \uc5f4 \ucd94\uac00",deleteTableRowLabel:"\ud589 \uc0ad\uc81c",deleteTableColumnLabel:"\uc5f4 \uc0ad\uc81c",colorTableCellTitle:"\ubc30\uacbd\uc0c9 \ud14c\uc774\ube14 \uc140",
tableContextMenuTitle:"\ud14c\uc774\ube14 \ucee8\ud14d\uc2a4\ud2b8 \uba54\ub274",_localized:{}},"dojox/editor/plugins/nls/PasteFromWord":{pasteFromWord:"\ub2e8\uc5b4\uc5d0\uc11c \ubd99\uc5ec\ub123\uae30",instructions:"\ub2e8\uc5b4\uc5d0\uc11c \uc544\ub798 \ud14d\uc2a4\ud2b8 \uc0c1\uc790\ub85c \ucee8\ud150\uce20\ub97c \ubd99\uc5ec \ub123\uc73c\uc2ed\uc2dc\uc624. \uc0bd\uc785\ud560 \ucee8\ud150\uce20\uac00 \uc900\ube44\ub418\uba74 \ubd99\uc5ec\ub123\uae30 \ub2e8\ucd94\ub97c \ub204\ub974\uc2ed\uc2dc\uc624. \ud14d\uc2a4\ud2b8 \uc0bd\uc785\uc744 \uc911\ub2e8\ud558\ub824\uba74 \ucde8\uc18c \ub2e8\ucd94\ub97c \ub204\ub974\uc2ed\uc2dc\uc624. ",
_localized:{}},"dojox/editor/plugins/nls/InsertAnchor":{insertAnchor:"\uae30\uc900 \uc704\uce58 \uc0bd\uc785",title:"\uae30\uc900 \uc704\uce58 \ud2b9\uc131",anchor:"\uc774\ub984:",text:"\uc124\uba85:",set:"\uc124\uc815",cancel:"\ucde8\uc18c",_localized:{}},"dojox/editor/plugins/nls/Blockquote":{blockquote:"Blockquote",_localized:{}},"dojox/editor/plugins/nls/LocalImage":{insertImageTitle:"\uc774\ubbf8\uc9c0 \uc0bd\uc785",url:"\uc774\ubbf8\uc9c0",browse:"\ucc3e\uc544\ubcf4\uae30...",text:"\uc124\uba85",
set:"\uc0bd\uc785",invalidMessage:"\uc62c\ubc14\ub974\uc9c0 \uc54a\uc740 \uc774\ubbf8\uc9c0 \ud30c\uc77c \uc720\ud615",prePopuTextUrl:"\uc774\ubbf8\uc9c0 URL \uc785\ub825",prePopuTextBrowse:"\ub610\ub294 \ub85c\uceec \ud30c\uc77c \ucc3e\uc544\ubcf4\uae30",_localized:{}}});
//# sourceMappingURL=pmbdojo_ko-kr.js.map